###############################################
#1. Set-up
##############################################
## Run these lines before doing anything (install package foreign and arm if necessary by uncommenting first line of code)

##uncommenting the line of code below to install necessary packages
#install.packages(c("foreign", "arm", "xtable"))

library(foreign)
library(arm)
library(xtable)


superpose.eb <-
function (x, y, ebl, ebu = ebl, length = 0.08, ...)
    arrows(x, y + ebu, x, y - ebl, angle = 90, code = 3,
    length = length, ...)

stderr <- function(x) sqrt(var(x, na.rm=TRUE)/length(x))



## Set working directory to place where the data file is
setwd("~/Dropbox/List Experiment Paper/Replication")

##############################################
#2. Figure 7
##############################################

# read in the data
dat <- read.dta("kramon_weghorst_poq2019.dta")
names(dat)
attach(dat)

## Standard Procedure:  Compute double list estimate and variance
S <- .5*((mean(dat$ST1, na.rm=TRUE) - mean(dat$SC1, na.rm=TRUE)) + (mean(dat$ST2, na.rm=TRUE) - mean(dat$SC2, na.rm=TRUE)))
A <- var(ST1, na.rm=TRUE)
B <- var(SC2, na.rm=TRUE)
C <- var(ST2, na.rm=TRUE)
D <- var(SC1, na.rm=TRUE)
r1 <- cor(ST1, SC2, use="complete")
r2 <- cor(ST2, SC1, use="complete")
varS <- .25*(A + B - 2*r1*sqrt(A)*sqrt(B) + C + D - 2*r2*sqrt(C)*sqrt(D))
nS <- length(dat[, 1])
seS <- sqrt(varS/nS)

##### Tick Procedure:  Compute double list estimate and variance
TT <- .5*((mean(dat$TT1, na.rm=TRUE) - mean(dat$TC1, na.rm=TRUE)) + (mean(dat$TT2, na.rm=TRUE) - mean(dat$TC2, na.rm=TRUE)))
A <- var(TT1, na.rm=TRUE)
B <- var(TC2, na.rm=TRUE)
C <- var(TT2, na.rm=TRUE)
D <- var(TC1, na.rm=TRUE)
r1 <- cor(TT1, TC2, use="complete")
r2 <- cor(TT2, TC1, use="complete")
varTT <- .25*(A + B - 2*r1*sqrt(A)*sqrt(B) + C + D - 2*r2*sqrt(C)*sqrt(D))
nTT <- length(dat[, 1])/2
seTT <- sqrt(varTT/nTT)

# Cartoon Procedure: Compute double list estimate and variance
CC <- .5*((mean(dat$CT1, na.rm=TRUE) - mean(dat$CC1, na.rm=TRUE)) + (mean(dat$CT2, na.rm=TRUE) - mean(dat$CC2, na.rm=TRUE)))
A <- var(CT1, na.rm=TRUE)
B <- var(CC2, na.rm=TRUE)
C <- var(CT2, na.rm=TRUE)
D <- var(CC1, na.rm=TRUE)
r1 <- cor(CT1, CC2, use="complete")
r2 <- cor(CT2, CC1, use="complete")
varC <- .25*(A + B - 2*r1*sqrt(A)*sqrt(B) + C + D - 2*r2*sqrt(C)*sqrt(D))
nC <- length(dat[, 1])/2
seC <- sqrt(varC/nC)

## Direct question estimate and variance
direct <- table(dat$violence)[2]/nS
vard <- direct*(1-direct)
sed <- sqrt(vard/nS)

## Produce Figure 7
nms <- c("Direct", "Standard", "Cartoon", "Tick")
ms <- as.numeric(c(direct, S, CC, TT))
ses <- as.numeric(c(sed, seS, seC, seTT))
cols <- c("dark grey", "grey", "light grey", "white")
max <- round(max(ms + ses) + .05, 1)
bar <- barplot(ms, las=1, names=nms, ylim=c(0, max), col=cols, main="", ylab="Proportion Who Agree That Violence Is Justified", xlab="Question Mode")
superpose.eb(bar, ms, ses)


##############################################
#2. Figure 8
##############################################

# read in the data
dat <- read.dta("kramon_weghorst_poq2019.dta")
names(dat)
table(dat$no_match)

dat <- dat[dat$no_match==1,]
dim(dat)

attach(dat)
w
## Standard Procedure:  Compute double list estimate and variance
S <- .5*((mean(dat$ST1, na.rm=TRUE) - mean(dat$SC1, na.rm=TRUE)) + (mean(dat$ST2, na.rm=TRUE) - mean(dat$SC2, na.rm=TRUE)))
A <- var(ST1, na.rm=TRUE)
B <- var(SC2, na.rm=TRUE)
C <- var(ST2, na.rm=TRUE)
D <- var(SC1, na.rm=TRUE)
r1 <- cor(ST1, SC2, use="complete")
r2 <- cor(ST2, SC1, use="complete")
varS <- .25*(A + B - 2*r1*sqrt(A)*sqrt(B) + C + D - 2*r2*sqrt(C)*sqrt(D))
nS <- length(dat[, 1])
seS <- sqrt(varS/nS)

##### Tick Procedure:  Compute double list estimate and variance
TT <- .5*((mean(dat$TT1, na.rm=TRUE) - mean(dat$TC1, na.rm=TRUE)) + (mean(dat$TT2, na.rm=TRUE) - mean(dat$TC2, na.rm=TRUE)))
A <- var(TT1, na.rm=TRUE)
B <- var(TC2, na.rm=TRUE)
C <- var(TT2, na.rm=TRUE)
D <- var(TC1, na.rm=TRUE)
r1 <- cor(TT1, TC2, use="complete")
r2 <- cor(TT2, TC1, use="complete")
varTT <- .25*(A + B - 2*r1*sqrt(A)*sqrt(B) + C + D - 2*r2*sqrt(C)*sqrt(D))
nTT <- length(dat[, 1])/2
seTT <- sqrt(varTT/nTT)

# Cartoon Procedure: Compute double list estimate and variance
CC <- .5*((mean(dat$CT1, na.rm=TRUE) - mean(dat$CC1, na.rm=TRUE)) + (mean(dat$CT2, na.rm=TRUE) - mean(dat$CC2, na.rm=TRUE)))
A <- var(CT1, na.rm=TRUE)
B <- var(CC2, na.rm=TRUE)
C <- var(CT2, na.rm=TRUE)
D <- var(CC1, na.rm=TRUE)
r1 <- cor(CT1, CC2, use="complete")
r2 <- cor(CT2, CC1, use="complete")
varC <- .25*(A + B - 2*r1*sqrt(A)*sqrt(B) + C + D - 2*r2*sqrt(C)*sqrt(D))
nC <- length(dat[, 1])/2
seC <- sqrt(varC/nC)

## Direct question estimate and variance
direct <- table(dat$violence)[2]/nS
vard <- direct*(1-direct)
sed <- sqrt(vard/nS)

## Produce the Figure summarizing results
nms <- c("Direct", "Standard", "Cartoon", "Tick")
ms <- as.numeric(c(direct, S, CC, TT))
ses <- as.numeric(c(sed, seS, seC, seTT))
cols <- c("dark grey", "grey", "light grey", "white")
max <- round(max(ms + ses) + .05, 1)
bar <- barplot(ms, las=1, names=nms, ylim=c(0, max), col=cols, main="", ylab="Proportion Who Agree That Violence Is Justified", xlab="Question Mode")
superpose.eb(bar, ms, ses)







##############################################
#2. Figure 9
##############################################
# read in the data
dat <- read.dta("kramon_weghorst_poq2019.dta")
dim(dat)

names(dat)
table(dat$education)
dat$subset <- dat$education
table(dat$subset)
dim(dat)
dat <- dat[dat$subset=="No Formal education"| dat$subset=="Only Primary" | dat$subset=="Some Secondary",]
dim(dat)

## Standard Procedure:  Compute double list estimate and variance
S <- .5*((mean(dat$ST1, na.rm=TRUE) - mean(dat$SC1, na.rm=TRUE)) + (mean(dat$ST2, na.rm=TRUE) - mean(dat$SC2, na.rm=TRUE)))
A <- var(dat$ST1, na.rm=TRUE)
B <- var(dat$SC2, na.rm=TRUE)
C <- var(dat$ST2, na.rm=TRUE)
D <- var(dat$SC1, na.rm=TRUE)
r1 <- cor(dat$ST1, dat$SC2, use="complete")
r2 <- cor(dat$ST2, dat$SC1, use="complete")
varS <- .25*(A + B - 2*r1*sqrt(A)*sqrt(B) + C + D - 2*r2*sqrt(C)*sqrt(D))
nS <- length(dat[, 1])
seS <- sqrt(varS/nS)

##### Tick Procedure:  Compute double list estimate and variance
TT <- .5*((mean(dat$TT1, na.rm=TRUE) - mean(dat$TC1, na.rm=TRUE)) + (mean(dat$TT2, na.rm=TRUE) - mean(dat$TC2, na.rm=TRUE)))
A <- var(dat$TT1, na.rm=TRUE)
B <- var(dat$TC2, na.rm=TRUE)
C <- var(dat$TT2, na.rm=TRUE)
D <- var(dat$TC1, na.rm=TRUE)
r1 <- cor(dat$TT1, dat$TC2, use="complete")
r2 <- cor(dat$TT2, dat$TC1, use="complete")
varTT <- .25*(A + B - 2*r1*sqrt(A)*sqrt(B) + C + D - 2*r2*sqrt(C)*sqrt(D))
nTT <- length(dat[, 1])/2
seTT <- sqrt(varTT/nTT)

# Cartoon Procedure: Compute double list estimate and variance
CC <- .5*((mean(dat$CT1, na.rm=TRUE) - mean(dat$CC1, na.rm=TRUE)) + (mean(dat$CT2, na.rm=TRUE) - mean(dat$CC2, na.rm=TRUE)))
A <- var(dat$CT1, na.rm=TRUE)
B <- var(dat$CC2, na.rm=TRUE)
C <- var(dat$CT2, na.rm=TRUE)
D <- var(dat$CC1, na.rm=TRUE)
r1 <- cor(dat$CT1, dat$CC2, use="complete")
r2 <- cor(dat$CT2, dat$CC1, use="complete")
varC <- .25*(A + B - 2*r1*sqrt(A)*sqrt(B) + C + D - 2*r2*sqrt(C)*sqrt(D))
nC <- length(dat[, 1])/2
seC <- sqrt(varC/nC)

## Direct question estimate and variance
direct <- table(dat$violence)[2]/nS
vard <- direct*(1-direct)
sed <- sqrt(vard/nS)

## Produce the Figure summarizing results
nms <- c("Direct", "Standard", "Cartoon", "Tick")
ms <- as.numeric(c(direct, S, CC, TT))
ses <- as.numeric(c(sed, seS, seC, seTT))
cols <- c("dark grey", "grey", "light grey", "white")
max <- round(max(ms + ses) + .05, 1)
bar <- barplot(ms, las=1, names=nms, ylim=c(0, max), col=cols, main="", ylab="Proportion Who Agree That Violence Is Justified", xlab="Question Mode")
superpose.eb(bar, ms, ses)



